@@ -1,12 +1,10 @@
 package Math::BivariateCDF;
 
-use 5.014002;
 use strict;
 use warnings;
 use Carp;
 
 require Exporter;
-use AutoLoader;
 
 our @ISA = qw(Exporter);
 
@@ -28,15 +26,13 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 require XSLoader;
 XSLoader::load('Math::BivariateCDF', $VERSION);
 
 # Preloaded methods go here.
 
-# Autoload methods go after =cut, and are processed by the autosplit program.
-
 1;
 __END__
 
@@ -55,6 +51,7 @@ Math::BivariateCDF - Perl extension for Bivariate CDF functions.
 =head1 DESCRIPTION
 
 This is a Perl wrapper for TOMS462 C library which evaluates the upper right tail of the bivariate normal distribution.
+Wikipedia: https://en.wikipedia.org/wiki/Multivariate_normal_distribution#Bivariate_case .
 
 =head2 EXPORT
 
